Arguments
formual
Formula that relates the observed cases (response)
to the expected cases (as an offset in the logscale, i.e.,
offset(log(expected))
stat
Name of the statistic to be computed.
data
Data frame with the data.
model
Model to be used when resampling in the test.
R
Number of simulations used in the test.
...
Any other argument needed by the test statistic. Check its
particular manual page for the list of extra arguments and examples.
alternative
Alternative hipotesis. This will depend on the test
statistic being used.