achisq.stat is the function that calculates the value of the statistic for the data.
achisq.boot is used when performing a non-parametric bootstrap.
achisq.pboot is used when performing a parametric bootstrap.
The actual value of the statistic depends on null hypotheses. If we consider that all the relative risks are equal to 1, the value is
T=$$\sum_i\frac{(O_i-E_i)^2}{E_i}$$
and the degrees of freedom are equal to the number of regions.
On the other hand, if we just consider relative risks to be equal, without specifying their value (i.e., $\lambda$ is unknown), $E_i$ must be substituted by $E_i\frac{O_+}{E_+}$ and the number of degrees of freedom is the number of regions minus one.
When internal standardization is used, null hypotheses must be all relative risks equal to 1 and the number of degrees of freedom is the number of regions minus one. This is due to the fact that, in this case, $O_+=E_+$.
Potthoff, R. F. and Whittinghill, M.(1966). Testing for Homogeneity: The Poisson Distribution. Biometrika 53, 183-190.