$$c=\frac{(n-1)\sum_i \sum_j W_{ij}(Z_i-Z_j)^2}{2(\sum_i\sum_jW_{ij})\sum_k (Z_k-\overline{Z})^2}$$
$W$ is a squared matrix which represents the relationship between each pair of regions. An usual approach is set $w_{ij}$ to 1 if regions $i$ and $j$ have a common boundary and 0 otherwise, or it may represent the inverse distance between the centroids of that two regions.
Small values of this statistic may indicate the presence of highly correlated areas, which may be a cluster.