opgam.iscluster.default is the function used by default, based on quantiles of the Poisson distribution.
opgam.iscluster.negbin is similar to the previous one but based on the Negative Binomial distribution. Local significance is estimated using bootstrap since it involves the sum of Negative Binomial variables.
opgam.iscluster.default(data, idx, idxorder, alpha, ...)
opgam.iscluster.negbin(data, idx, idxorder, alpha, mle, R=999, ...)The vector returned by this functions can be of size higher than four, but the first four elements must be those stated in this manual page (and in the same order).
More example can be found in the implementations of other scan methods, such as Besag and Newell's, and Kulldorff and Nagarwalla's.