This method is based on creating a grid over the study area. Each point of
the grid is taken to be the centre of all circles that contain up to a
fraction of the total population. This is calculated by suming all the
population of the regions whose centroids fall inside the circle. For each one
of these balls, the likelihood ratio of the next test hypotheses is computed:lcl{
$H_0$ : $p=q$
$H_1$ : $p>q$
}
where p is the probability of being a case inside the ball and
q the probability of being a case outside it. Then, the ball
where the maximum of the likelihood ratio is achieved is selected and its
value is tested to assess whether it is significant or not.
There are two possible statistics, depending on the model assumed for the
data, which can be Bernouilli or Poisson. The value of the likelihood ratio
statistic is
$$\max_{z \in Z}\frac{L(z)}{L_0}$$
where Z is the set of ball at a given point, z an element of
this set, $L_0$ is the likelihood under the null hypotheses and
$L(z)$ is the likelihood under the alternative hypotheses. The
actual formulae involved in the calculation can be found in the reference
given below.