The Geographical Analysis Machine was developed by Openshaw
et al. to perform geographical studies of the relationship between
different types of cancer and their proximity to nuclear plants.In this method, a grid of a fixed step is built along the study region, and
small balls of a given radius are created at each point of the grid. Local
observed and expected number of cases and population are calculated and a
function is used to assess whether the current ball is a cluster or not. For
more information about this function see opgam.iscluster.default, which
is the default function used.
If the obverved number of cases excess a critical value, which is calculated
by a function passed as an argument, then that circle is marked as a possible
cluster. At the end, all possible clusters are drawn on a map. Clusters may be
easily identified then.
Notice that we have follow a pretty flexible approach, since user-implemented
functions can be used to detect clusters, such as those related to
ovedispersion (Pearson's Chi square statistic, Potthoff-Whittinghill's
statistic) or autocorrelation (Moran's I statistic and Geary's c statistic),
or a bootstrap procedure, although it is not recommended because it can
be VERY slow.