Learn R Programming

DCluster (version 0.2-2)

rmultin: Generate random observations from a multinomial distribution

Description

This function generates a random observation from a multinomial distribution.

Usage

rmultin(n, p)

Arguments

n
Total size (and NOT the number of variables involved in the multinomial distribution).
p
Vector of probabilities. The sum of all its elements must be one.

Value

  • A vector with the sample which has been generated.

Examples

Run this code
for(i in 1:10)
	print(rmultin(10, c(1/3, 1/3, 1/3) ))

Run the code above in your browser using DataLab