Stone's Test is used to assess risk around given locations (i. e., a putative
pollution source). The null hypotheses is that relative risks are constant
across areas, while the alternative is that there is descending trend in
relative risks as distance to the focus increases. That islcl{
$H_0$ : $\theta_1 = \ldots = \theta_n = \lambda$
$H_1$ : $\theta_1 \geq \ldots \geq \theta_n$
}
Supposing data sorted by distance to the putative pollution source, Stone's
statistic is as follows:
$$\max_{j}(\frac{\sum _{i=1}^j O_i}{\sum _{i=1}^j E_i)}$$
Depending on whether $\lambda$ is known (usually 1) or not,
$E_i$ may need a minor correction, which are not done automatically.
See achisq manual page for details.