Learn R Programming

DCluster (version 0.2-2)

tango: Tango's statistic for general clustering

Description

Tango's statistic to perform a general clustering test is expressed as follows:

$$T = (r-p)^{'} A (r-p)$$

where $r^{'} = [O_1/O_+, \ldots, O_n/O_+]$, $p^{'}=[E_1/E_+, \ldots, E_n/E_+]$ and $A$ is a matrix of closeness which measures the cloneness between two zones (the higher the closer).

Tango proposes to take $A_{ij}=\exp{-D_{ij}/\phi}$, where $D_{ij}$ is the distance between centroids of regions i and j, and $\phi$ is a constant that measures how strong is the relationship between regions in a general way.

Arguments

References

Tango, Toshiro (1995). A Class of Tests for Detecting 'General' and 'Focused' Clustering of Rare Diseases. Statistics in Medicine 14, 2323-2334.

See Also

DCluster, tango.stat, tango.boot, tango.pboot