lognormalEB: Empirical Bayes Smoothing using a log-normal model
Description
Smooth relative risks from a set of expected and observed number of cases
using a log-Normal model as proposed by Clayton and Kaldor (1987).
There are estimated by
$\tilde{\beta}_i =\log((O_i+1/2)/E_i)$
in order to prevent taking the logarithm of zero.
If this case, the log-relative risks are assumed be independant and to have a
normal distribution with mean $\varphi$ and variance
$\sigma^2$. Clayton y Kaldor (1987) use the EM algorithm to
develop estimates of these two parameters which are used to compute the
Empirical Bayes estimate of $b_i$. The formula is not listed here, but
it can be consulted in Clayton and Kaldor (1987).
Usage
lognormalEB(Observed, Expected, maxiter = 20, tol = 1e-05)
Arguments
Observed
Vector of observed cases.
Expected
Vector of expected cases.
maxiter
Maximum number of iterations allowed.
tol
Tolerance used to stop the iterative procedure.
Value
A list of four elements:
nNumber of regions.
phiEstimate of $\varphi$.
sigma2Estimate of $\sigma^2$.
smthrrVector of smoothed relative risks.
References
Clayton, David and Kaldor, John (1987). Empirical Bayes Estimates of Age-standardized Relative Risks for Use in Disease Mapping. Biometrics 43, 671-681.